@@ -6,7 +6,7 @@ warnings.simplefilter("ignore")
 
 from akerbp.mlops.core import logger, config
 locals().update(config.getenv)
-logging=logger.get_logger()
+logging=logger.get_logger("mlops_cdf")
 
 service = import_module(f"akerbp.mlops.services.{service_name}").service
 
