@@ -17,6 +17,7 @@ class EnvVar():
     service_name: str
     local_deployment: Optional[str]
     google_project_id: Optional[str]
+    deployment_platform: Optional[str]
 
     def __post_init__(self):
         envs = ["dev", "test", "prod"]
@@ -28,13 +29,19 @@ class EnvVar():
         service_names = ["training", "prediction"]
         if self.service_name not in service_names:
             m = (f"Service name: allowed values are {service_names}"
-                 f", got '{self.env}'")
+                 f", got '{self.service_name}'")
             raise ValueError(m)
 
         local_deployments = ["True", None]
         if self.local_deployment not in local_deployments:
             m = (f"Local deployment: allowed values are {local_deployments}"
-                 f", got '{self.env}'")
+                 f", got '{self.local_deployment}'")
+            raise ValueError(m)
+
+        deployment_platforms = ["cdf", "gc", None]
+        if self.deployment_platform not in deployment_platforms:
+            m = (f"Local deployment: allowed values are {deployment_platforms}"
+                 f", got '{self.deployment_platforms}'")
             raise ValueError(m)
 
 # Read environmental variables
@@ -42,7 +49,8 @@ _getenv=EnvVar(
     env=os.getenv('ENV'), 
     service_name=os.getenv('SERVICE_NAME'), 
     local_deployment=os.getenv('LOCAL_DEPLOYMENT'),
-    google_project_id=os.getenv('GOOGLE_PROJECT_ID')
+    google_project_id=os.getenv('GOOGLE_PROJECT_ID'),
+    deployment_platform=os.getenv('DEPLOYMENT_PLATFORM'),
 )
 getenv=asdict(_getenv)
 logging.debug(f"{getenv=}")
@@ -54,9 +62,9 @@ class CdfKeys():
     functions: Optional[str]
 
 _api_keys = CdfKeys(
-   data = os.environ['COGNITE_API_KEY_DATA'],
-   files = os.environ['COGNITE_API_KEY_FILES'],
-   functions = os.environ['COGNITE_API_KEY_FUNCTIONS']
+   data = os.getenv('COGNITE_API_KEY_DATA'),
+   files = os.getenv('COGNITE_API_KEY_FILES'),
+   functions = os.getenv('COGNITE_API_KEY_FUNCTIONS')
 )
 api_keys = asdict(_api_keys)
 
