@@ -71,9 +71,6 @@ def deploy_model(model_settings):
         test_service(c.model_name)
     else:
         logging.warning("Model test file is missing! Didn't run tests")
-    # Project settings file isn't needed anymore
-    logging.debug("Delete project settings from deployment folder")
-    os.remove('mlops_settings.py')
 
 
     logging.info(f"Deploy {function_name} to {c.deployment_platform}")
