@@ -9,7 +9,7 @@ import subprocess
 from akerbp.mlops.core import logger, config 
 
 
-logging=logger.get_logger(name='MLOps')
+logging=logger.get_logger(name='mlops_deployment')
 
 locals().update(config.getenv)
 
