@@ -89,8 +89,10 @@ def run_container(image_name, service_account):
     Run container with a service account
     """
     logging.info(f"Run container, {image_name=}, {service_account=}")
-    envs = [f"{k.upper()}={v}" for k,v in config.getenv.items() if v]
-    env_list_string=','.join(envs)
+    env_vars = {k.upper():v for k,v in config.getenv.items() if v}
+    env_vars.update(dict(DEPLOYMENT_PLATFORM='cdf'))    
+    env_vars = [f"{k}={v}" for k,v in env_vars.items() if v]
+    env_vars=','.join(env_vars)
     
     subprocess.check_call(
         (f"gcloud run deploy {image_name} "
@@ -101,7 +103,7 @@ def run_container(image_name, service_account):
           "--no-user-output-enabled "
           "--memory=512M "
          f"--service-account {service_account} "
-         f"--set-env-vars={env_list_string} "
+         f"--set-env-vars={env_vars} "
           "--quiet"
         ), shell=True)
 
